@@ -38,8 +38,12 @@
 #ifndef __OPAL_ACCOUNT_H__
 #define __OPAL_ACCOUNT_H__
 
+#include <opal/pres_ent.h>
+
 #include "services.h"
+#include "presence-core.h"
 #include "account-core.h"
+#include "personal-details.h"
 #include "account.h"
 #include "form.h"
 #include "bank-impl.h"
@@ -51,7 +55,10 @@ namespace Opal
    * @internal
    * @{
    */
-  class Account: public Ekiga::Account
+  class Account:
+    public Ekiga::Account,
+    public Ekiga::PresencePublisher,
+    public Ekiga::PresenceFetcher
   {
 public:
 
@@ -142,6 +149,14 @@ public:
 
     boost::signal0<void> trigger_saving;
 
+    /*
+     * This is because an opal account is an Ekiga::PresencePublisher
+     * and an Ekiga::PresenceFetcher
+     */
+    void publish (const Ekiga::PersonalDetails& details);
+    void fetch (const std::string uri);
+    void unfetch (const std::string uri);
+
     /* This method is public to be called by an opal endpoint, which will push
      * this Opal::Account's new registration state
      * Notice : it's very wrong to make that a const method, but Opal seems to
@@ -177,6 +192,18 @@ private:
     std::string password;
     Type type;
 
+    PSafePtr<OpalPresentity> presentity;
+    void setup_presentity ();
+
+    PDECLARE_PresenceChangeNotifier (Account, OnPresenceChange);
+
+    std::set<std::string> watched_uris; // FIXME: that is wrong... the opal code should do that!
+    OpalPresenceInfo::State personal_state; // FIXME: shouldn't the opal code do that too?
+    std::string presence_status; // FIXME: shouldn't the opal code do that too?
+    void presence_status_in_main (std::string uri,
+				  std::string presence,
+				  std::string status);
+
     Ekiga::ServiceCore & core;
   };
 
