@@ -38,9 +38,11 @@
 #ifndef __OPAL_BANK_H__
 #define __OPAL_BANK_H__
 
+#include "presence-core.h"
 #include "bank-impl.h"
 #include "opal-account.h"
 #include "services.h"
+#include "runtime.h"
 
 namespace Opal
 {
@@ -51,6 +53,8 @@ namespace Opal
    */
   class Bank: 
       public Ekiga::BankImpl<Account>,
+      public Ekiga::PresencePublisher,
+      public Ekiga::PresenceFetcher,
       public Ekiga::Service
   {
 public:
@@ -67,6 +71,15 @@ public:
     const std::string get_description () const
     { return "\tStores the opal accounts"; }
 
+    /*
+     * this object is an Ekiga::PresenceFetcher and an Ekiga::PresencePublisher
+     */
+    void publish (const Ekiga::PersonalDetails& details);
+
+    void fetch (const std::string uri);
+
+    void unfetch (const std::string uri);
+
     void new_account (Account::Type acc_type,
                       std::string username = "",
                       std::string password = "");
@@ -99,6 +112,7 @@ private:
               unsigned timeout);
 
     void save () const;
+
   };
 
   /**
