@@ -27,7 +27,7 @@
 
 
 /*
- *                         manager.cpp  -  description
+ *                         opal-call-manager.cpp  -  description
  *                         ---------------------------
  *   begin                : Sat Dec 23 2000
  *   copyright            : (C) 2000-2006 by Damien Sandras
@@ -43,16 +43,17 @@
 #include "pcss-endpoint.h"
 
 #include "call-core.h"
-#include "opal-call.h"
 #include "opal-codec-description.h"
 #include "videoinput-info.h"
 
 #include "call-manager.h"
 #include "form-request-simple.h"
 
+#include <stdlib.h>
+
 static  bool same_codec_desc (Ekiga::CodecDescription a, Ekiga::CodecDescription b)
-{ 
-  return (a.name == b.name && a.rate == b.rate); 
+{
+  return (a.name == b.name && a.rate == b.rate);
 }
 
 
@@ -64,8 +65,8 @@ public:
 
   StunDetector (const std::string & _server,
 		Opal::CallManager& _manager,
-                GAsyncQueue* _queue) 
-    : PThread (1000, AutoDeleteThread), 
+                GAsyncQueue* _queue)
+    : PThread (1000, AutoDeleteThread),
       server (_server),
       manager (_manager),
       queue (_queue)
@@ -78,15 +79,12 @@ public:
   {
     g_async_queue_unref (queue);
   }
-  
-  void Main () 
+
+  void Main ()
   {
-    PSTUNClient::NatTypes* result = NULL;
+    PSTUNClient::NatTypes result = manager.SetSTUNServer (server);
 
-    result = (PSTUNClient::NatTypes*)g_malloc0 (sizeof (PSTUNClient::NatTypes));
-    *result = manager.SetSTUNServer (server);
-
-    g_async_queue_push (queue, result);
+    g_async_queue_push (queue, GUINT_TO_POINTER ((guint)result + 1));
   };
 
 private:
@@ -101,32 +99,42 @@ using namespace Opal;
 
 /* The class */
 CallManager::CallManager (Ekiga::ServiceCore & _core)
-: core (_core)
+  : core (_core)
 {
-  /* Initialise the endpoint paramaters */
+  /* Initialise the endpoint parameters */
+#if P_HAS_IPV6
+  char * ekiga_ipv6 = getenv("EKIGA_IPV6");
+  // use IPv6 instead of IPv4 if EKIGA_IPV6 env var is set
+  if (ekiga_ipv6 && PIPSocket::IsIpAddressFamilyV6Supported())
+    PIPSocket::SetDefaultIpAddressFamilyV6();
+  else
+    PIPSocket::SetDefaultIpAddressFamilyV4();
+#else
   PIPSocket::SetDefaultIpAddressFamilyV4();
+#endif
   SetAutoStartTransmitVideo (true);
   SetAutoStartReceiveVideo (true);
   SetUDPPorts (5000, 5100);
   SetTCPPorts (30000, 30100);
   SetRtpIpPorts (5000, 5100);
-  
+
   pcssEP = NULL;
 
   forward_on_no_answer = false;
   forward_on_busy = false;
   unconditional_forward = false;
   stun_enabled = false;
+  auto_answer = false;
 
   // Create video devices
   PVideoDevice::OpenArgs video = GetVideoOutputDevice();
   video.deviceName = "EKIGAOUT";
   SetVideoOutputDevice (video);
-  
+
   video = GetVideoOutputDevice();
   video.deviceName = "EKIGAIN";
   SetVideoPreviewDevice (video);
-  
+
   video = GetVideoInputDevice();
   video.deviceName = "EKIGA";
   SetVideoInputDevice (video);
@@ -140,19 +148,8 @@ CallManager::CallManager (Ekiga::ServiceCore & _core)
   SetMediaFormatOrder (PStringArray ());
   SetMediaFormatMask (PStringArray ());
 
-  call_core = core.get ("call-core");
-  {
-    gmref_ptr<Ekiga::Runtime> smart = core.get ("runtime");
-    smart->reference (); // take a reference in the main thread
-    runtime = &*smart;
-  }
-
   // used to communicate with the StunDetector
-#if GLIB_CHECK_VERSION(2,16,0)
-  queue = g_async_queue_new_full (g_free);
-#else
   queue = g_async_queue_new ();
-#endif
 
   PInterfaceMonitor::GetInstance().SetRefreshInterval (15000);
 }
@@ -163,21 +160,6 @@ CallManager::~CallManager ()
   ClearAllCalls (OpalConnection::EndedByLocalUser, true);
 
   g_async_queue_unref (queue);
-  runtime->unreference ();
-}
-
-
-void CallManager::start ()
-{
-  if (stun_enabled) {
-    
-    // Ready
-    new StunDetector (stun_server, *this, queue);
-    patience = 20;
-    runtime->run_in_main (sigc::mem_fun (this, &CallManager::HandleSTUNResult), 1);
-  }
-  else
-    ready.emit ();
 }
 
 
@@ -191,7 +173,7 @@ void CallManager::set_display_name (const std::string & name)
 
 const std::string & CallManager::get_display_name () const
 {
-  return display_name; 
+  return display_name;
 }
 
 
@@ -212,7 +194,7 @@ void CallManager::set_echo_cancellation (bool enabled)
        call != NULL;
        ++call) {
 
-    for (int i = 0; 
+    for (int i = 0;
          i < 2;
          i++) {
 
@@ -233,7 +215,7 @@ bool CallManager::get_echo_cancellation () const
 {
   OpalEchoCanceler::Params ec = GetEchoCancelParams ();
 
-  return (ec.m_mode == OpalEchoCanceler::Cancelation); 
+  return (ec.m_mode == OpalEchoCanceler::Cancelation);
 }
 
 
@@ -247,7 +229,7 @@ void CallManager::set_maximum_jitter (unsigned max_val)
        call != NULL;
        ++call) {
 
-    for (int i = 0; 
+    for (int i = 0;
          i < 2;
          i++) {
 
@@ -272,7 +254,7 @@ void CallManager::set_maximum_jitter (unsigned max_val)
 
 unsigned CallManager::get_maximum_jitter () const
 {
-  return GetMaxAudioJitterDelay (); 
+  return GetMaxAudioJitterDelay ();
 }
 
 
@@ -293,7 +275,7 @@ void CallManager::set_silence_detection (bool enabled)
        call != NULL;
        ++call) {
 
-    for (int i = 0; 
+    for (int i = 0;
          i < 2;
          i++) {
 
@@ -332,6 +314,18 @@ unsigned CallManager::get_reject_delay () const
 }
 
 
+void CallManager::set_auto_answer (bool enabled)
+{
+  auto_answer = enabled;
+}
+
+
+bool CallManager::get_auto_answer (void) const
+{
+  return auto_answer;
+}
+
+
 const Ekiga::CodecList & CallManager::get_codecs () const
 {
   return codecs;
@@ -353,8 +347,8 @@ void CallManager::set_codecs (Ekiga::CodecList & _codecs)
   GetAllowedFormats (all_media_formats);
   Ekiga::CodecList all_codecs = Opal::CodecList (all_media_formats);
 
-  // 
-  // Clean the CodecList given as paramenter : remove unsupported codecs and 
+  //
+  // Clean the CodecList given as paramenter : remove unsupported codecs and
   // add missing codecs at the end of the list
   //
 
@@ -365,10 +359,10 @@ void CallManager::set_codecs (Ekiga::CodecList & _codecs)
        it != all_codecs.end ();
        it++) {
 
-    Ekiga::CodecList::iterator i  = 
+    Ekiga::CodecList::iterator i  =
       search_n (_codecs.begin (), _codecs.end (), 1, *it, same_codec_desc);
     if (i == _codecs.end ()) {
-      _codecs.push_back (*it);
+      _codecs.append (*it);
     }
   }
 
@@ -377,17 +371,17 @@ void CallManager::set_codecs (Ekiga::CodecList & _codecs)
        it != _codecs.end ();
        it++) {
 
-    Ekiga::CodecList::iterator i  = 
+    Ekiga::CodecList::iterator i  =
       search_n (all_codecs.begin (), all_codecs.end (), 1, *it, same_codec_desc);
     if (i == all_codecs.end ()) {
-      _codecs.erase (it);
+      _codecs.remove (it);
       it = _codecs.begin ();
     }
   }
   codecs = _codecs;
 
 
-  // 
+  //
   // Update OPAL
   //
   Ekiga::CodecList::iterator codecs_it;
@@ -402,12 +396,12 @@ void CallManager::set_codecs (Ekiga::CodecList & _codecs)
 
     // Find the OpalMediaFormat corresponding to the Ekiga::CodecDescription
     if (active) {
-      for (j = 0 ; 
+      for (j = 0 ;
            j < all_media_formats.GetSize () ;
            j++) {
 
         if (name == (const char *) all_media_formats [j].GetEncodingName ()
-            && rate == all_media_formats [j].GetClockRate ()) {
+            && (rate == all_media_formats [j].GetClockRate () || name == "G722")) {
 
           // Found something
           order += all_media_formats [j];
@@ -415,16 +409,30 @@ void CallManager::set_codecs (Ekiga::CodecList & _codecs)
       }
     }
   }
+  
+
+  // Add the PCSS codecs
+  all_media_formats = pcssEP->GetMediaFormats ();
+  for (int j = 0 ;
+       j < all_media_formats.GetSize () ;
+       j++)
+    order += all_media_formats [j];
+
 
   // Build the mask
   all_media_formats = OpalTranscoder::GetPossibleFormats (pcssEP->GetMediaFormats ());
   all_media_formats.Remove (order);
 
-  for (int i = 0 ; 
-       i < all_media_formats.GetSize () ; 
+  for (int i = 0 ;
+       i < all_media_formats.GetSize () ;
        i++)
     mask += all_media_formats [i];
 
+  // Blacklist IM protocols for now
+  mask += "T.140";
+  mask += "MSRP";
+  mask += "SIP-IM";
+
   // Update the OpalManager
   SetMediaFormatMask (mask);
   SetMediaFormatOrder (order);
@@ -460,7 +468,7 @@ bool CallManager::get_unconditional_forward ()
   return unconditional_forward;
 }
 
-void CallManager::set_udp_ports (unsigned min_port, 
+void CallManager::set_udp_ports (unsigned min_port,
                                  unsigned max_port)
 {
   if (min_port < max_port) {
@@ -471,28 +479,39 @@ void CallManager::set_udp_ports (unsigned min_port,
 }
 
 
-void CallManager::get_udp_ports (unsigned & min_port, 
+void CallManager::get_udp_ports (unsigned & min_port,
                                  unsigned & max_port) const
 {
   min_port = GetUDPPortBase ();
   max_port = GetUDPPortMax ();
 }
 
-void CallManager::set_tcp_ports (unsigned min_port, 
+void CallManager::set_tcp_ports (unsigned min_port,
                                  unsigned max_port)
 {
-  if (min_port < max_port) 
+  if (min_port < max_port)
     SetTCPPorts (min_port, max_port);
 }
 
 
-void CallManager::get_tcp_ports (unsigned & min_port, 
+void CallManager::get_tcp_ports (unsigned & min_port,
                                  unsigned & max_port) const
 {
   min_port = GetTCPPortBase ();
   max_port = GetTCPPortMax ();
 }
 
+void
+CallManager::get_rtp_tos (unsigned &tos) const
+{
+  tos = GetMediaTypeOfService ();
+}
+
+void
+CallManager::set_rtp_tos (unsigned tos)
+{
+  SetMediaTypeOfService (tos);
+}
 
 void CallManager::set_stun_server (const std::string & server)
 {
@@ -503,6 +522,14 @@ void CallManager::set_stun_server (const std::string & server)
 void CallManager::set_stun_enabled (bool enabled)
 {
   stun_enabled = enabled;
+  if (stun_enabled) {
+
+    // Ready
+    new StunDetector (stun_server, *this, queue);
+    patience = 20;
+    Ekiga::Runtime::run_in_main (boost::bind (&CallManager::HandleSTUNResult, this), 1);
+  } else
+    ready ();
 }
 
 
@@ -529,33 +556,33 @@ void CallManager::set_video_options (const CallManager::VideoOptions & options)
     OpalMediaFormat media_format = media_formats_list [i];
     if (media_format.GetMediaType() == OpalMediaType::Video ()) {
 
-      media_format.SetOptionInteger (OpalVideoFormat::FrameWidthOption (), 
-                                     Ekiga::VideoSizes [options.size].width);  
-      media_format.SetOptionInteger (OpalVideoFormat::FrameHeightOption (), 
-                                     Ekiga::VideoSizes [options.size].height);  
+      media_format.SetOptionInteger (OpalVideoFormat::FrameWidthOption (),
+                                     Ekiga::VideoSizes [options.size].width);
+      media_format.SetOptionInteger (OpalVideoFormat::FrameHeightOption (),
+                                     Ekiga::VideoSizes [options.size].height);
       media_format.SetOptionInteger (OpalVideoFormat::FrameTimeOption (),
                                      (int) (90000 / (options.maximum_frame_rate > 0 ? options.maximum_frame_rate : 30)));
-      media_format.SetOptionInteger (OpalVideoFormat::MaxBitRateOption (), 
+      media_format.SetOptionInteger (OpalVideoFormat::MaxBitRateOption (),
                                      (options.maximum_received_bitrate > 0 ? options.maximum_received_bitrate : 4096) * 1000);
-      media_format.SetOptionInteger (OpalVideoFormat::TargetBitRateOption (), 
+      media_format.SetOptionInteger (OpalVideoFormat::TargetBitRateOption (),
                                      (options.maximum_transmitted_bitrate > 0 ? options.maximum_transmitted_bitrate : 48) * 1000);
-      media_format.SetOptionInteger (OpalVideoFormat::MinRxFrameWidthOption(), 
+      media_format.SetOptionInteger (OpalVideoFormat::MinRxFrameWidthOption(),
                                      160);
-      media_format.SetOptionInteger (OpalVideoFormat::MinRxFrameHeightOption(), 
+      media_format.SetOptionInteger (OpalVideoFormat::MinRxFrameHeightOption(),
                                      120);
-      media_format.SetOptionInteger (OpalVideoFormat::MaxRxFrameWidthOption(), 
+      media_format.SetOptionInteger (OpalVideoFormat::MaxRxFrameWidthOption(),
                                      1920);
-      media_format.SetOptionInteger (OpalVideoFormat::MaxRxFrameHeightOption(), 
+      media_format.SetOptionInteger (OpalVideoFormat::MaxRxFrameHeightOption(),
                                      1088);
-      media_format.AddOption(new OpalMediaOptionUnsigned (OpalVideoFormat::TemporalSpatialTradeOffOption (), 
-                                                          true, OpalMediaOption::NoMerge, 
-                                                          options.temporal_spatial_tradeoff));  
-      media_format.SetOptionInteger (OpalVideoFormat::TemporalSpatialTradeOffOption(), 
-                                     (options.temporal_spatial_tradeoff > 0 ? options.temporal_spatial_tradeoff : 31));  
-      media_format.AddOption(new OpalMediaOptionUnsigned (OpalVideoFormat::MaxFrameSizeOption (), 
+      media_format.AddOption(new OpalMediaOptionUnsigned (OpalVideoFormat::TemporalSpatialTradeOffOption (),
+                                                          true, OpalMediaOption::NoMerge,
+                                                          options.temporal_spatial_tradeoff));
+      media_format.SetOptionInteger (OpalVideoFormat::TemporalSpatialTradeOffOption(),
+                                     (options.temporal_spatial_tradeoff > 0 ? options.temporal_spatial_tradeoff : 31));
+      media_format.AddOption(new OpalMediaOptionUnsigned (OpalVideoFormat::MaxFrameSizeOption (),
                                                           true, OpalMediaOption::NoMerge, 1400));
-      media_format.SetOptionInteger (OpalVideoFormat::MaxFrameSizeOption (), 
-                                     1400);  
+      media_format.SetOptionInteger (OpalVideoFormat::MaxFrameSizeOption (),
+                                     1400);
 
       if ( media_format.GetName() != "YUV420P" &&
            media_format.GetName() != "RGB32" &&
@@ -563,10 +590,12 @@ void CallManager::set_video_options (const CallManager::VideoOptions & options)
 
         media_format.SetOptionBoolean (OpalVideoFormat::RateControlEnableOption(),
                                        true);
-        media_format.SetOptionInteger (OpalVideoFormat::RateControlWindowSizeOption(),
-                                       500);
-        media_format.SetOptionInteger (OpalVideoFormat::RateControlMaxFramesSkipOption(),
-                                       1);
+        /* the following two options have been removed, what can they be replaced with?
+	   media_format.SetOptionInteger (OpalVideoFormat::RateControlWindowSizeOption(),
+	   500);
+	   media_format.SetOptionInteger (OpalVideoFormat::RateControlMaxFramesSkipOption(),
+	   1);
+        */
       }
 
       OpalMediaFormat::SetRegisteredMediaFormat(media_format);
@@ -578,7 +607,7 @@ void CallManager::set_video_options (const CallManager::VideoOptions & options)
        call != NULL;
        ++call) {
 
-    for (int i = 0; 
+    for (int i = 0;
          i < 2;
          i++) {
 
@@ -590,7 +619,7 @@ void CallManager::set_video_options (const CallManager::VideoOptions & options)
 
           OpalMediaFormat mediaFormat = stream->GetMediaFormat ();
           mediaFormat.SetOptionInteger (OpalVideoFormat::TemporalSpatialTradeOffOption(),
-                                        (options.temporal_spatial_tradeoff > 0 ? options.temporal_spatial_tradeoff : 31));  
+                                        (options.temporal_spatial_tradeoff > 0 ? options.temporal_spatial_tradeoff : 31));
           mediaFormat.SetOptionInteger (OpalVideoFormat::TargetBitRateOption (),
                                         (options.maximum_transmitted_bitrate > 0 ? options.maximum_transmitted_bitrate : 48) * 1000);
           mediaFormat.ToNormalisedOptions();
@@ -621,13 +650,13 @@ void CallManager::get_video_options (CallManager::VideoOptions & options) const
       }
       options.size = j;
 
-      options.maximum_frame_rate = 
+      options.maximum_frame_rate =
         (int) (90000 / media_format.GetOptionInteger (OpalVideoFormat::FrameTimeOption ()));
-      options.maximum_received_bitrate = 
+      options.maximum_received_bitrate =
         (int) (media_format.GetOptionInteger (OpalVideoFormat::MaxBitRateOption ()) / 1000);
-      options.maximum_transmitted_bitrate = 
+      options.maximum_transmitted_bitrate =
         (int) (media_format.GetOptionInteger (OpalVideoFormat::TargetBitRateOption ()) / 1000);
-      options.temporal_spatial_tradeoff = 
+      options.temporal_spatial_tradeoff =
         media_format.GetOptionInteger (OpalVideoFormat::TemporalSpatialTradeOffOption ());
 
       break;
@@ -635,22 +664,41 @@ void CallManager::get_video_options (CallManager::VideoOptions & options) const
   }
 }
 
-
-OpalCall *CallManager::CreateCall ()
+void
+CallManager::create_call_in_main (Opal::Call* call)
 {
-  gmref_ptr<Opal::Call> call (new Opal::Call (*this, core));
-  call_core->add_call (call, gmref_ptr<CallManager>(this));
+  boost::shared_ptr<Ekiga::CallCore> call_core = core.get<Ekiga::CallCore> ("call-core");
 
-  return &*call;
+  call_core->add_call (boost::shared_ptr<Opal::Call>(call),
+		       boost::dynamic_pointer_cast<CallManager>(shared_from_this ()));
 }
 
+OpalCall *CallManager::CreateCall (void *uri)
+{
+  Opal::Call* call = 0;
+
+  if (uri != 0)
+    call = new Opal::Call (*this, core, (const char *) uri);
+  else
+    call = new Opal::Call (*this, core, "");
+
+  Ekiga::Runtime::run_in_main (boost::bind (&CallManager::create_call_in_main, this, call));
+
+  return call;
+}
+
+void
+CallManager::emit_removed_in_main (Ekiga::Call* call)
+{
+  call->removed ();
+}
 
 void
 CallManager::DestroyCall (OpalCall *_call)
 {
   Ekiga::Call *call = dynamic_cast<Ekiga::Call *> (_call);
 
-  runtime->emit_signal_in_main(call->removed);
+  Ekiga::Runtime::run_in_main(boost::bind (&CallManager::emit_removed_in_main, this, call));
 }
 
 
@@ -665,15 +713,15 @@ CallManager::OnClosedMediaStream (const OpalMediaStream & stream)
 }
 
 
-bool 
+bool
 CallManager::OnOpenMediaStream (OpalConnection & connection,
-                              OpalMediaStream & stream)
+				OpalMediaStream & stream)
 {
   OpalMediaFormatList list = pcssEP->GetMediaFormats ();
   if (!OpalManager::OnOpenMediaStream (connection, stream))
     return FALSE;
 
-  if (list.FindFormat(stream.GetMediaFormat()) == list.end ()) 
+  if (list.FindFormat(stream.GetMediaFormat()) == list.end ())
     dynamic_cast <Opal::Call &> (connection.GetCall ()).OnOpenMediaStream (stream);
 
   return TRUE;
@@ -684,7 +732,7 @@ void CallManager::GetAllowedFormats (OpalMediaFormatList & full_list)
 {
   OpalMediaFormatList list = OpalTranscoder::GetPossibleFormats (pcssEP->GetMediaFormats ());
   std::list<std::string> black_list;
-   
+
   black_list.push_back ("GSM-AMR");
   black_list.push_back ("Linear-16-Stereo-48kHz");
   black_list.push_back ("LPC-10");
@@ -712,52 +760,57 @@ void CallManager::GetAllowedFormats (OpalMediaFormatList & full_list)
 void
 CallManager::HandleSTUNResult ()
 {
-  PSTUNClient::NatTypes* result = NULL;
+  gboolean error = false;
+  gboolean got_answer = false;
 
-  result = (PSTUNClient::NatTypes*)g_async_queue_try_pop (queue);
+  if (g_async_queue_length (queue) > 0) {
 
-  if (result != NULL || patience == 0) {
+    PSTUNClient::NatTypes result
+      = (PSTUNClient::NatTypes)(GPOINTER_TO_UINT (g_async_queue_pop (queue))-1);
+    got_answer = true;
 
-    if (patience == 0
-	|| *result == PSTUNClient::SymmetricNat
-	|| *result == PSTUNClient::BlockedNat
-	|| *result == PSTUNClient::PartialBlockedNat) {
+    if (result == PSTUNClient::SymmetricNat
+	|| result == PSTUNClient::BlockedNat
+	|| result == PSTUNClient::PartialBlockedNat) {
 
-      ReportSTUNError (_("Ekiga did not manage to configure your network settings automatically. You can"
-			 " still use it, but you need to configure your network settings manually.\n\n"
-			 "Please see http://wiki.ekiga.org/index.php/Enable_port_forwarding_manually for"
-			 " instructions"));
+      error = true;
     } else {
 
-    for (Ekiga::CallManager::iterator iter = begin ();
-	 iter != end ();
-	 ++iter) 
-      (*iter)->set_listen_port ((*iter)->get_listen_interface ().port);
+      for (Ekiga::CallManager::iterator iter = begin ();
+	   iter != end ();
+	   ++iter)
+	(*iter)->set_listen_port ((*iter)->get_listen_interface ().port);
+      ready ();
     }
+  } else if (patience == 0) {
 
-    ready.emit ();
+    error = true;
+  }
 
-    if (result != NULL)
-      g_free (result);
+  if (error) {
 
-  } else {
+    ReportSTUNError (_("Ekiga did not manage to configure your network settings automatically. You can"
+		       " still use it, but you need to configure your network settings manually.\n\n"
+		       "Please see http://wiki.ekiga.org/index.php/Enable_port_forwarding_manually for"
+		       " instructions"));
+    ready ();
+  } else if (!got_answer) {
+
+    patience--;
+    Ekiga::Runtime::run_in_main (boost::bind (&CallManager::HandleSTUNResult, this), 1);
 
-      patience--;
-      runtime->run_in_main (sigc::mem_fun (this,
-					  &CallManager::HandleSTUNResult),
-			    1);
   }
 }
 
 void
 CallManager::ReportSTUNError (const std::string error)
 {
-  // notice we're in for an infinite loop if nobody ever reports to the user!
-  if ( !call_core->errors.handle_request (error)) {
+  boost::shared_ptr<Ekiga::CallCore> call_core = core.get<Ekiga::CallCore> ("call-core");
 
-    runtime->run_in_main (sigc::bind (sigc::mem_fun (this,
-						     &CallManager::ReportSTUNError),
-				      error),
-			  10);
+  // notice we're in for an infinite loop if nobody ever reports to the user!
+  if ( !call_core->errors (error)) {
+
+    Ekiga::Runtime::run_in_main (boost::bind (&CallManager::ReportSTUNError, this, error),
+				 10);
   }
 }
