@@ -79,9 +79,12 @@ void GMVideoInputManager_ptlib::get_devices(std::vector <Ekiga::VideoInputDevice
 
       for (PINDEX j = 0; devices_array[j] != NULL; j++) {
 
-        /* linux USB subsystem uses latin-1 encoding, Windows codepage,
-           while ekiga uses utf-8 */
-        device.name = latin2utf (devices_array[j]);
+#ifdef WIN32
+        /* Windows uses codepage encoding for device name, while ekiga uses utf-8 */
+        device.name = codepage2utf (devices_array[j]);
+#else
+        device.name = devices_array[j];
+#endif
         devices.push_back(device);
       }
       free (devices_array);
@@ -117,7 +120,13 @@ bool GMVideoInputManager_ptlib::open (unsigned width, unsigned height, unsigned
   expectedFrameSize = (width * height * 3) >> 1;
 
   pvideo_format = (PVideoDevice::VideoFormat)current_state.format;
-  input_device = PVideoInputDevice::CreateOpenedDevice (current_state.device.source, utf2latin (current_state.device.name), FALSE);  // reencode back to latin-1 or codepage
+  input_device = PVideoInputDevice::CreateOpenedDevice (current_state.device.source,
+#ifdef WIN32
+                 utf2codepage (current_state.device.name),  // reencode back to codepage
+#else
+                 current_state.device.name,
+#endif
+                 FALSE);
 
   Ekiga::VideoInputErrorCodes error_code = Ekiga::VI_ERROR_NONE;
   if (!input_device)
@@ -136,7 +145,7 @@ bool GMVideoInputManager_ptlib::open (unsigned width, unsigned height, unsigned
 
   if (error_code != Ekiga::VI_ERROR_NONE) {
     PTRACE(1, "GMVideoInputManager_ptlib\tEncountered error " << error_code << " while opening device ");
-    Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &GMVideoInputManager_ptlib::device_error_in_main), current_state.device, error_code));
+    Ekiga::Runtime::run_in_main (boost::bind (&GMVideoInputManager_ptlib::device_error_in_main, this, current_state.device, error_code));
     return false;
   }
 
@@ -151,7 +160,7 @@ bool GMVideoInputManager_ptlib::open (unsigned width, unsigned height, unsigned
   settings.contrast = contrast >> 8;
   settings.modifyable = true;
 
-  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &GMVideoInputManager_ptlib::device_opened_in_main), current_state.device, settings));
+  Ekiga::Runtime::run_in_main (boost::bind (&GMVideoInputManager_ptlib::device_opened_in_main, this, current_state.device, settings));
 
   return true;
 }
@@ -164,7 +173,7 @@ void GMVideoInputManager_ptlib::close()
     input_device = NULL;
   }
   current_state.opened = false;
-  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &GMVideoInputManager_ptlib::device_closed_in_main), current_state.device));
+  Ekiga::Runtime::run_in_main (boost::bind (&GMVideoInputManager_ptlib::device_closed_in_main, this, current_state.device));
 }
 
 bool GMVideoInputManager_ptlib::get_frame_data (char *data)
@@ -232,18 +241,18 @@ void
 GMVideoInputManager_ptlib::device_opened_in_main (Ekiga::VideoInputDevice device,
 						  Ekiga::VideoInputSettings settings)
 {
-  device_opened.emit (device, settings);
+  device_opened (device, settings);
 }
 
 void
 GMVideoInputManager_ptlib::device_closed_in_main (Ekiga::VideoInputDevice device)
 {
-  device_closed.emit (device);
+  device_closed (device);
 }
 
 void
 GMVideoInputManager_ptlib::device_error_in_main (Ekiga::VideoInputDevice device,
 						 Ekiga::VideoInputErrorCodes code)
 {
-  device_error.emit (device, code);
+  device_error (device, code);
 }
