@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,9 +35,8 @@
  *
  */
 
-#include "config.h"
-
 #include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 
 #include "chat-window.h"
 #include "simple-chat-page.h"
@@ -49,7 +48,7 @@ struct _ChatWindowPrivate
   {}
 
   Ekiga::ChatCore& core;
-  std::list<sigc::connection> connections;
+  std::list<boost::signals::connection> connections;
 
   GtkWidget* notebook;
 };
@@ -62,7 +61,7 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static GObjectClass* parent_class = NULL;
+G_DEFINE_TYPE (ChatWindow, chat_window, GM_TYPE_WINDOW);
 
 /* helper (declaration) */
 
@@ -77,7 +76,7 @@ static void on_escaped (GtkWidget *widget,
                         gpointer data);
 
 static void on_switch_page (GtkNotebook* notebook,
-			    GtkNotebookPage* page,
+			    gpointer page_,
 			    guint num,
 			    gpointer data);
 
@@ -89,11 +88,11 @@ static void on_message_notice_event (GtkWidget* page,
 				     gpointer data);
 
 static bool on_dialect_added (ChatWindow* self,
-			      Ekiga::Dialect& dialect);
+			      Ekiga::DialectPtr dialect);
 static bool on_simple_chat_added (ChatWindow* self,
-				  Ekiga::SimpleChat& chat);
+				  Ekiga::SimpleChatPtr chat);
 static bool on_multiple_chat_added (ChatWindow* self,
-				    Ekiga::MultipleChat& chat);
+				    Ekiga::MultipleChatPtr chat);
 static void on_some_chat_user_requested (ChatWindow* self,
 					 GtkWidget* page);
 
@@ -160,7 +159,7 @@ on_escaped (GtkWidget */*widget*/,
 
 static void
 on_switch_page (G_GNUC_UNUSED GtkNotebook* notebook,
-		G_GNUC_UNUSED GtkNotebookPage* page_,
+		G_GNUC_UNUSED gpointer page_,
 		guint num,
 		gpointer data)
 {
@@ -266,34 +265,33 @@ on_message_notice_event (GtkWidget* page,
 
 static bool
 on_dialect_added (ChatWindow* self,
-		  Ekiga::Dialect& dialect)
+		  Ekiga::DialectPtr dialect)
 {
-  self->priv->connections.push_front (dialect.simple_chat_added.connect (sigc::hide_return (sigc::bind<0> (sigc::ptr_fun (on_simple_chat_added), self))));
-  self->priv->connections.push_front (dialect.multiple_chat_added.connect (sigc::hide_return (sigc::bind<0> (sigc::ptr_fun (on_multiple_chat_added), self))));
+  self->priv->connections.push_front (dialect->simple_chat_added.connect (boost::bind (&on_simple_chat_added, self, _1)));
+  self->priv->connections.push_front (dialect->multiple_chat_added.connect (boost::bind (&on_multiple_chat_added, self, _1)));
 
-  dialect.visit_simple_chats (sigc::bind<0> (sigc::ptr_fun (on_simple_chat_added), self));
-  dialect.visit_multiple_chats (sigc::bind<0> (sigc::ptr_fun (on_multiple_chat_added), self));
+  dialect->visit_simple_chats (boost::bind (&on_simple_chat_added, self, _1));
+  dialect->visit_multiple_chats (boost::bind (&on_multiple_chat_added, self, _1));
 
   return true;
 }
 
 static bool
 on_simple_chat_added (ChatWindow* self,
-		      Ekiga::SimpleChat &chat)
+		      Ekiga::SimpleChatPtr chat)
 {
   GtkWidget* page = NULL;
   GtkWidget* hbox = NULL;
   GtkWidget* label = NULL;
   GtkWidget* close_button = NULL;
   GtkWidget* close_image = NULL;
-  gint num;
 
   page = simple_chat_page_new (chat);
   hbox = gtk_hbox_new (FALSE, 2);
 
-  label = gtk_label_new (chat.get_title ().c_str ());
+  label = gtk_label_new (chat->get_title ().c_str ());
   g_object_set_data_full (G_OBJECT (label), "base-title",
-			  g_strdup (chat.get_title ().c_str ()),
+			  g_strdup (chat->get_title ().c_str ()),
 			  g_free);
   
   close_button = gtk_button_new ();
@@ -314,33 +312,32 @@ on_simple_chat_added (ChatWindow* self,
   g_object_set_data (G_OBJECT (hbox), "close-button-widget", close_button);
   gtk_widget_show_all (hbox);
 
-  num = gtk_notebook_append_page (GTK_NOTEBOOK (self->priv->notebook),
-				  page, hbox);
+  gtk_notebook_append_page (GTK_NOTEBOOK (self->priv->notebook),
+			    page, hbox);
   gtk_widget_show (page);
   g_signal_connect (page, "message-notice-event",
 		    G_CALLBACK (on_message_notice_event), self);
 
-  self->priv->connections.push_front (chat.user_requested.connect (sigc::bind (sigc::ptr_fun (on_some_chat_user_requested), self, page)));
+  self->priv->connections.push_front (chat->user_requested.connect (boost::bind (&on_some_chat_user_requested, self, page)));
 
   return true;
 }
 
 static bool
 on_multiple_chat_added (ChatWindow* self,
-			Ekiga::MultipleChat &chat)
+			Ekiga::MultipleChatPtr chat)
 {
   GtkWidget* page = NULL;
   GtkWidget* label = NULL;
-  gint num;
 
   page = multiple_chat_page_new (chat);
-  label = gtk_label_new (chat.get_title ().c_str ());
+  label = gtk_label_new (chat->get_title ().c_str ());
 
-  num = gtk_notebook_append_page (GTK_NOTEBOOK (self->priv->notebook),
-				  page, label);
+  gtk_notebook_append_page (GTK_NOTEBOOK (self->priv->notebook),
+			    page, label);
   gtk_widget_show_all (page);
 
-  self->priv->connections.push_front (chat.user_requested.connect (sigc::bind (sigc::ptr_fun (on_some_chat_user_requested), self, page)));
+  self->priv->connections.push_front (chat->user_requested.connect (boost::bind (&on_some_chat_user_requested, self, page)));
 
   return true;
 }
@@ -359,16 +356,6 @@ on_some_chat_user_requested (ChatWindow* self,
 
 /* GObject code */
 
-static void
-chat_window_dispose (GObject* obj)
-{
-  ChatWindow* self = NULL;
-
-  self = CHAT_WINDOW (obj);
-
-  parent_class->dispose (obj);
-}
-
 static void
 chat_window_finalize (GObject* obj)
 {
@@ -376,7 +363,7 @@ chat_window_finalize (GObject* obj)
 
   self = CHAT_WINDOW (obj);
 
-  for (std::list<sigc::connection>::iterator iter
+  for (std::list<boost::signals::connection>::iterator iter
 	 = self->priv->connections.begin ();
        iter != self->priv->connections.end ();
        ++iter)
@@ -385,20 +372,14 @@ chat_window_finalize (GObject* obj)
   delete self->priv;
   self->priv = NULL;
 
-  parent_class->finalize (obj);
+  G_OBJECT_CLASS (chat_window_parent_class)->finalize (obj);
 }
 
 static void
-chat_window_class_init (gpointer g_class,
-			G_GNUC_UNUSED gpointer class_data)
+chat_window_class_init (ChatWindowClass* klass)
 {
-  ChatWindowClass* chat_window_class = NULL;
-  GObjectClass* gobject_class = NULL;
+  GObjectClass* gobject_class = G_OBJECT_CLASS (klass);
 
-  parent_class = (GObjectClass*) g_type_class_peek_parent (g_class);
-
-  gobject_class = (GObjectClass*) g_class;
-  gobject_class->dispose = chat_window_dispose;
   gobject_class->finalize = chat_window_finalize;
 
   signals[UNREAD_COUNT] =
@@ -419,46 +400,13 @@ chat_window_class_init (gpointer g_class,
 		  NULL, NULL,
 		  g_cclosure_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
-
-  /* FIXME: is it useful? */
-  chat_window_class = (ChatWindowClass*)g_class;
-  chat_window_class->unread_count = NULL;
 }
 
 static void
-chat_window_init (GTypeInstance* instance,
-		  G_GNUC_UNUSED gpointer g_class)
+chat_window_init (ChatWindow* self)
 {
   /* we can't do much here since we get the Chat as reference... */
-  gtk_window_set_title (GTK_WINDOW (instance), _("Chat Window"));
-}
-
-GType
-chat_window_get_type ()
-{
-  static GType result = 0;
-
-  if (result == 0) {
-
-    static const GTypeInfo info = {
-      sizeof (ChatWindowClass),
-      NULL,
-      NULL,
-      chat_window_class_init,
-      NULL,
-      NULL,
-      sizeof (ChatWindow),
-      0,
-      chat_window_init,
-      NULL
-    };
-
-    result = g_type_register_static (GM_WINDOW_TYPE,
-				     "ChatWindow",
-				     &info, (GTypeFlags) 0);
-  }
-
-  return result;
+  gtk_window_set_title (GTK_WINDOW (self), _("Chat Window"));
 }
 
 /* public api */
@@ -492,8 +440,8 @@ chat_window_new (Ekiga::ChatCore& core,
   g_signal_connect (result->priv->notebook, "switch-page",
 		    G_CALLBACK (on_switch_page), result);
 
-  result->priv->connections.push_front (core.dialect_added.connect (sigc::hide_return(sigc::bind<0>(sigc::ptr_fun (on_dialect_added), result))));
-  core.visit_dialects (sigc::bind<0>(sigc::ptr_fun (on_dialect_added), result));
+  result->priv->connections.push_front (core.dialect_added.connect (boost::bind (&on_dialect_added, result, _1)));
+  core.visit_dialects (boost::bind (&on_dialect_added, result, _1));
 
   return (GtkWidget*)result;
 }
