@@ -63,14 +63,14 @@ gtk_frontend_init (Ekiga::ServiceCore &core,
 {
   bool result = false;
 
-  gmref_ptr<Ekiga::PresenceCore> presence_core = core.get ("presence-core");
-  gmref_ptr<Ekiga::ContactCore> contact_core = core.get ("contact-core");
-  gmref_ptr<Ekiga::ChatCore> chat_core = core.get ("chat-core");
-  gmref_ptr<History::Source> history_source = core.get ("call-history-store");
+  boost::shared_ptr<Ekiga::PresenceCore> presence_core = core.get<Ekiga::PresenceCore> ("presence-core");
+  boost::shared_ptr<Ekiga::ContactCore> contact_core = core.get<Ekiga::ContactCore> ("contact-core");
+  boost::shared_ptr<Ekiga::ChatCore> chat_core = core.get<Ekiga::ChatCore> ("chat-core");
+  boost::shared_ptr<History::Source> history_source = core.get<History::Source> ("call-history-store");
 
   if (presence_core && contact_core && chat_core && history_source) {
 
-    gmref_ptr<GtkFrontend> gtk_frontend (new GtkFrontend (core));
+    boost::shared_ptr<GtkFrontend> gtk_frontend (new GtkFrontend (core));
     core.add (gtk_frontend);
     result = true;
   }
@@ -80,19 +80,14 @@ gtk_frontend_init (Ekiga::ServiceCore &core,
 
 GtkFrontend::GtkFrontend (Ekiga::ServiceCore &core)
 {
-  gmref_ptr<Ekiga::PresenceCore> presence_core = core.get ("presence-core");
-  gmref_ptr<Ekiga::ContactCore> contact_core = core.get ("contact-core");
-  gmref_ptr<Ekiga::ChatCore> chat_core = core.get ("chat-core");
-  gmref_ptr<History::Source> history_source = core.get ("call-history-store");
-  gmref_ptr<History::Book> history_book = history_source->get_book ();
+  boost::shared_ptr<Ekiga::ContactCore> contact_core = core.get<Ekiga::ContactCore> ("contact-core");
+  boost::shared_ptr<Ekiga::ChatCore> chat_core = core.get<Ekiga::ChatCore> ("chat-core");
 
-  roster_view = roster_view_gtk_new (*presence_core);
-  call_history_view = call_history_view_gtk_new (history_book);
   addressbook_window =
-    addressbook_window_new_with_key (*contact_core, "/apps/ekiga/general/user_interface/addressbook_window");
+    addressbook_window_new_with_key (*contact_core, "/apps/" PACKAGE_NAME "/general/user_interface/addressbook_window");
   chat_window =
     chat_window_new (*chat_core,
-		     "/apps/ekiga/general/user_interface/chat_window");
+		     "/apps/" PACKAGE_NAME "/general/user_interface/chat_window");
 }
 
 
@@ -115,12 +110,6 @@ const std::string GtkFrontend::get_description () const
 }
 
 
-const GtkWidget *GtkFrontend::get_roster_view () const
-{
-  return roster_view;
-}
-
-
 const GtkWidget *GtkFrontend::get_addressbook_window () const
 {
   return addressbook_window;
@@ -131,10 +120,3 @@ const GtkWidget *GtkFrontend::get_chat_window () const
 {
   return chat_window;
 }
-
-
-const GtkWidget *
-GtkFrontend::get_call_history_view () const
-{
-  return call_history_view;
-}
