@@ -97,7 +97,6 @@
  */
 typedef struct _DataBase
 {
-  gboolean is_watched;
   GData *entries;
 } DataBase;
 
@@ -122,7 +121,6 @@ struct _GmConfEntry
   union {
     gboolean boolean;
     gint integer;
-    gfloat floa;
     gchar *string;
     GSList *list;
     GmConfEntry *redirect; /* for GM_CONF_OTHER entries */
@@ -174,12 +172,10 @@ static void string_list_deep_destroy (GSList *);
 
 static gchar *string_from_bool (const gboolean);
 static gchar *string_from_int (const gint);
-static gchar *string_from_float (const gfloat);
 static gchar *string_from_list (const GSList *);
 
 static gboolean bool_from_string (const gchar *);
 static gint int_from_string (const gchar *);
-static gfloat float_from_string (const gchar *);
 static GSList *list_from_string (const gchar *);
 
 /* notifier functions */
@@ -204,10 +200,7 @@ static void entry_set_bool (GmConfEntry *, const gboolean);
 static gint entry_get_int (const GmConfEntry *);
 static void entry_set_int (GmConfEntry *, const gint);
 
-static gfloat entry_get_float (const GmConfEntry *);
-static void entry_set_float (GmConfEntry *, const gfloat);
-
-static const gchar *entry_get_string (const GmConfEntry *);
+static gchar *entry_get_string (const GmConfEntry *);
 static void entry_set_string (GmConfEntry *, const gchar *);
 
 static GSList *entry_get_list (const GmConfEntry *);
@@ -253,15 +246,10 @@ static void database_save_entry (GQuark quark, gpointer data,
 				 gpointer user_data);
 static gboolean database_save_file (DataBase *, const gchar *);
 static void database_add_entry (DataBase *, GmConfEntry *);
-static void database_remove_namespace_in_datalist (GQuark key_id,
-						   gpointer data,
-						   gpointer user_data);
-static void database_remove_namespace (DataBase *, const gchar *);
 static GmConfEntry *database_get_entry_for_key (DataBase *, const gchar *);
 static GmConfEntry *database_get_entry_for_key_create (DataBase *,
 						       const gchar *);
 
-static void database_set_watched (DataBase *, const gboolean);
 static void database_notify_on_namespace (DataBase *, const gchar *);
 
 /*
@@ -320,19 +308,6 @@ string_from_int (const gint val)
   return result;
 }
 
-static gchar *
-string_from_float (const gfloat val)
-{
-  gchar *result = NULL;
-  GString *buffer = NULL;
-
-  buffer = g_string_new (NULL);
-  g_string_printf (buffer, "%f", val);
-
-  result = g_string_free (buffer, FALSE);
-  return result;
-}
-
 static gchar *
 string_from_list (const GSList *val)
 {
@@ -391,18 +366,6 @@ int_from_string (const gchar *str)
   return result;
 }
 
-static gfloat
-float_from_string (const gchar *str)
-{
-  gfloat result;
-  int err;
-
-  g_return_val_if_fail (str != NULL, 0);
-
-  err = sscanf (str, "%f", &result);
-  return result;
-}
-
 static GSList *
 list_from_string (const gchar *str)
 {
@@ -540,8 +503,6 @@ entry_destroy (gpointer ent)
     break;
   case GM_CONF_INT:
     break;
-  case GM_CONF_FLOAT:
-    break;
   case GM_CONF_STRING:
     g_free (entry->value.string);
     break;
@@ -630,30 +591,12 @@ entry_set_int (GmConfEntry *entry,
   entry->value.boolean = val;
 }
 
-static gfloat
-entry_get_float (const GmConfEntry *entry)
-{
-  check_entry_type_return (entry, GM_CONF_FLOAT, 0);
-
-  return entry->value.floa;
-}
-
-static void
-entry_set_float (GmConfEntry *entry,
-		 const gfloat val)
-{
-  g_return_if_fail (entry != NULL);
-
-  entry->type = GM_CONF_FLOAT;
-  entry->value.floa = val;
-}
-
-static const gchar *
+static gchar*
 entry_get_string (const GmConfEntry *entry)
 {
   check_entry_type_return (entry, GM_CONF_STRING, NULL);
 
-  return entry->value.string;
+  return g_strdup (entry->value.string);
 }
 
 static void
@@ -766,7 +709,6 @@ database_new ()
   DataBase *db = NULL;
 
   db = g_new (DataBase, 1);
-  db->is_watched = FALSE;
   db->entries = NULL;
   g_datalist_init (&db->entries);
   return db;
@@ -859,8 +801,6 @@ sch_parser_characters (G_GNUC_UNUSED GMarkupParseContext *context,
       entry_set_type (parser->entry, GM_CONF_BOOL);
     else if (strcmp (text, "int") == 0)
       entry_set_type (parser->entry, GM_CONF_INT);
-    else if (strcmp (text, "float") == 0)
-      entry_set_type (parser->entry, GM_CONF_FLOAT);
     else if (strcmp (text, "string") == 0)
       entry_set_type (parser->entry, GM_CONF_STRING);
     else if (strcmp (text, "list") == 0)
@@ -876,9 +816,6 @@ sch_parser_characters (G_GNUC_UNUSED GMarkupParseContext *context,
     case GM_CONF_INT:
       entry_set_int (parser->entry, int_from_string (text));
       break;
-    case GM_CONF_FLOAT:
-      entry_set_float (parser->entry, float_from_string (text));
-      break;
     case GM_CONF_STRING:
       entry_set_string (parser->entry, text);
       break;
@@ -956,7 +893,7 @@ database_save_entry (G_GNUC_UNUSED GQuark quark,
   GmConfEntry *entry = NULL;
   GIOChannel *io = NULL;
   gchar *value = NULL;
-  const gchar *txt = NULL;
+  gchar *txt = NULL;
 
   g_return_if_fail (data != NULL);
   g_return_if_fail (user_data != NULL);
@@ -980,9 +917,6 @@ database_save_entry (G_GNUC_UNUSED GQuark quark,
   case GM_CONF_INT:
     g_io_channel_write_chars (io, "int", -1, NULL, NULL);
     break;
-  case GM_CONF_FLOAT:
-    g_io_channel_write_chars (io, "float", -1, NULL, NULL);
-    break;
   case GM_CONF_STRING:
     g_io_channel_write_chars (io, "string", -1, NULL, NULL);
     break;
@@ -1006,14 +940,13 @@ database_save_entry (G_GNUC_UNUSED GQuark quark,
   case GM_CONF_INT:
     value = string_from_int (entry_get_int (entry));
     break;
-  case GM_CONF_FLOAT:
-    value = string_from_float (entry_get_float (entry));
-    break;
   case GM_CONF_STRING:
     txt = entry_get_string (entry);
-    if (txt != NULL)
+    if (txt != NULL) {
+
       value = g_markup_escape_text (txt, -1);
-    else
+      g_free (txt);
+    } else
       value = g_strdup ("");
     break;
   case GM_CONF_LIST:
@@ -1072,44 +1005,6 @@ database_add_entry (DataBase *db,
 			    entry, entry_destroy);
 }
 
-static void
-database_remove_namespace_in_datalist (G_GNUC_UNUSED GQuark key_id,
-				       gpointer data,
-				       gpointer user_data)
-{
-  GmConfEntry *entry = NULL;
-  NamespcWrapper *wrapper = NULL;
-  const gchar *key = NULL;
-
-  g_return_if_fail (data != NULL);
-  g_return_if_fail (user_data != NULL);
-
-  entry = (GmConfEntry *)data;
-  wrapper = (NamespcWrapper *)user_data;
-  key = entry_get_key (entry);
-
-  if (g_str_has_prefix (key, wrapper->namespc))
-    g_datalist_remove_data (wrapper->datalist, key);
-
-}
-
-static void
-database_remove_namespace (DataBase *db,
-			   const gchar *namespc)
-{
-  NamespcWrapper *wrapper = NULL;
-
-  g_return_if_fail (db != NULL);
-  g_return_if_fail (namespc != NULL);
-
-  wrapper = g_new (NamespcWrapper, 1);
-  wrapper->datalist = &db->entries;
-  wrapper->namespc = namespc;
-  g_datalist_foreach (&db->entries,
-		      database_remove_namespace_in_datalist, wrapper);
-  g_free (wrapper);
-}
-
 static GmConfEntry *
 database_get_entry_for_key (DataBase *db,
 			    const gchar *key)
@@ -1142,22 +1037,13 @@ database_get_entry_for_key_create (DataBase *db,
   return entry;
 }
 
-static void
-database_set_watched (DataBase *db,
-		      const gboolean bool)
-{
-  g_return_if_fail (db != NULL);
-
-  db->is_watched = bool;
-}
-
 static void
 database_notify_on_namespace (DataBase *db,
 			      const gchar *namespac)
 {
   GmConfEntry *parent_entry = NULL, *entry = NULL;
   gchar *key = NULL;
-
+  gchar* key_ptr = NULL;
 
   g_return_if_fail (db != NULL);
   g_return_if_fail (namespac != NULL);
@@ -1167,13 +1053,11 @@ database_notify_on_namespace (DataBase *db,
 
   g_return_if_fail (entry != NULL);
 
-  if (db->is_watched == FALSE)
-    return;
-
-  for (key = g_strdup (namespac);
-       key[0] != 0;
-       g_strrstr (key, "/")[0] = 0) {
-    parent_entry = database_get_entry_for_key (db, key);
+  key = g_strdup (namespac);
+  for (key_ptr = key;
+       key_ptr[0] != 0;
+       g_strrstr (key_ptr, "/")[0] = 0) {
+    parent_entry = database_get_entry_for_key (db, key_ptr);
     if (parent_entry != NULL) {
       if (entry_get_type (parent_entry) == GM_CONF_OTHER)
 	entry_set_redirect (parent_entry, entry);
@@ -1271,12 +1155,7 @@ gm_conf_init ()
   gm_conf_set_bool ("/desktop/gnome/interface/menus_have_icons", TRUE);
 
   /* automatic savings */
-#if GLIB_CHECK_VERSION (2, 14, 0)
   g_timeout_add_seconds (5, (GSourceFunc)saveconf_timer_callback, NULL);
-#else
-  g_timeout_add (5000, (GSourceFunc)saveconf_timer_callback, NULL);
-#endif
-
 }
 
 
@@ -1302,22 +1181,6 @@ gm_conf_save ()
   g_free (user_conf);
 }
 
-void
-gm_conf_watch ()
-{
-  DataBase *db = database_get_default ();
-
-  database_set_watched (db, TRUE);
-}
-
-void
-gm_conf_unwatch ()
-{
-  DataBase *db = database_get_default ();
-
-  database_set_watched (db, FALSE);
-}
-
 gpointer
 gm_conf_notifier_add (const gchar *namespac,
 		      GmConfNotifier func,
@@ -1388,7 +1251,7 @@ gm_conf_entry_get_int (GmConfEntry *entry)
   return entry_get_int (entry);
 }
 
-const gchar *
+gchar *
 gm_conf_entry_get_string (GmConfEntry *entry)
 {
   g_return_val_if_fail (entry != NULL, NULL);
@@ -1468,38 +1331,6 @@ gm_conf_get_int (const gchar *key)
   return entry_get_int (entry);
 }
 
-void
-gm_conf_set_float (const gchar *key,
-		   const float val)
-{
-  DataBase *db = database_get_default ();
-  GmConfEntry *entry = NULL;
-
-  g_return_if_fail (key != NULL);
-
-  entry = database_get_entry_for_key_create (db, key);
-
-  g_return_if_fail (entry != NULL);
-
-  entry_set_float (entry, val);
-  database_notify_on_namespace (db, entry_get_key (entry));
-}
-
-gfloat
-gm_conf_get_float (const gchar *key)
-{
-  DataBase *db = database_get_default ();
-  GmConfEntry *entry = NULL;
-
-  g_return_val_if_fail (key != NULL, 0);
-
-  entry = database_get_entry_for_key (db, key);
-
-  check_entry_for_key_return (entry, key, 0);
-
-  return entry_get_float (entry);
-}
-
 void
 gm_conf_set_string (const gchar *key,
 		    const gchar *val)
@@ -1529,7 +1360,7 @@ gm_conf_get_string (const gchar *key)
 
   check_entry_for_key_return (entry, key, NULL);
 
-  return g_strdup (entry_get_string (entry));
+  return entry_get_string (entry);
 }
 
 void
@@ -1564,16 +1395,6 @@ gm_conf_get_string_list (const gchar *key)
   return string_list_deep_copy (entry_get_list (entry));
 }
 
-void
-gm_conf_destroy (const gchar *namespac)
-{
-  DataBase *db = database_get_default ();
-
-  g_return_if_fail (namespac != NULL);
-
-  database_remove_namespace (db, namespac);
-}
-
 gboolean
 gm_conf_is_key_writable (const gchar *key)
 {
