@@ -40,16 +40,9 @@
 #include "config.h"
 
 #include "callbacks.h"
-#include "main.h"
-#include "misc.h"
 
 #include "ekiga.h"
-
-#include "gmentrydialog.h"
-#include "gmconf.h"
-#include "gmdialog.h"
-#include "gmconnectbutton.h"
-#include "gmmenuaddon.h"
+#include "gmwindow.h"
 #include "gmstockicons.h"
 
 #ifdef WIN32
@@ -61,68 +54,11 @@
 
 #include <glib/gi18n.h>
 
-#undef GTK_DISABLE_DEPRECATED
-#ifdef HAVE_GNOME
-#include <libgnome/gnome-help.h>
-#endif
-
 
 /* The callbacks */
-gboolean
-delete_window_cb (GtkWidget *widget,
-                  G_GNUC_UNUSED GdkEvent *event,
-                  G_GNUC_UNUSED gpointer data)
-{
-  gnomemeeting_window_hide (GTK_WIDGET (widget));
-
-  return TRUE;
-}
-
-static void
-show_window (GtkWidget *window)
-{
-  if (!gnomemeeting_window_is_visible (window))
-    gnomemeeting_window_show (window);
-  else
-    gtk_window_present (GTK_WINDOW (window));
-}
 
 void
-show_window_cb (G_GNUC_UNUSED GtkWidget *widget,
-		gpointer data)
-{
-  show_window (GTK_WIDGET (data));
-}
-
-
-void
-show_assistant_window_cb (G_GNUC_UNUSED GtkWidget *widget,
-                          G_GNUC_UNUSED gpointer data)
-{
-  GtkWidget *window = GnomeMeeting::Process ()->GetAssistantWindow ();
-  show_window (window);
-}
-
-void
-show_prefs_window_cb (G_GNUC_UNUSED GtkWidget *widget,
-                      G_GNUC_UNUSED gpointer data)
-{
-  GtkWidget *window = GnomeMeeting::Process ()->GetPrefsWindow ();
-  show_window (window);
-}
-
-
-void
-hide_window_cb (G_GNUC_UNUSED GtkWidget *widget,
-		gpointer data)
-{
-  if (gnomemeeting_window_is_visible (GTK_WIDGET (data)))
-    gnomemeeting_window_hide (GTK_WIDGET (data));
-}
-
-
-void
-about_callback (G_GNUC_UNUSED GtkWidget *widget, 
+about_callback (G_GNUC_UNUSED GtkWidget *widget,
 		gpointer parent_window)
 {
   const gchar *authors [] = {
@@ -130,9 +66,10 @@ about_callback (G_GNUC_UNUSED GtkWidget *widget,
       "",
       N_("Contributors:"),
       "Howard Chu <hyc@symas.com>",
+      "Eugen Dedu <eugen.dedu@pu-pm.univ-fcomte.fr>",
       "Yannick Defais <sevmek@free.fr>",
       "Steve Fr\303\251cinaux <code@istique.net>",
-      "Kilian Krause <kk@verfaction.de>", 
+      "Kilian Krause <kk@verfaction.de>",
       "Vincent Luba <luba@novacom.be>",
       "Julien Puydt <julien.puydt@laposte.net>",
       "Luc Saillard <luc@saillard.org>",
@@ -151,11 +88,11 @@ about_callback (G_GNUC_UNUSED GtkWidget *widget,
       N_("See AUTHORS file for full credits"),
       NULL
   };
-	
+
   authors [2] = gettext (authors [2]);
   authors [12] = gettext (authors [12]);
   authors [20] = gettext (authors [20]);
-  
+
   const gchar *documenters [] = {
     "Damien Sandras <dsandras@seconix.com>",
     "Christopher Warner <zanee@kernelcode.com>",
@@ -191,9 +128,9 @@ GNU GPL for all the rest of the software thus combined.")
   if (strcmp (translator_credits, "translator-credits") == 0)
     translator_credits = "No translators, English by\n"
         "Damien Sandras <dsandras@seconix.com>";
- 
+
   const gchar *comments =  _("Ekiga is full-featured SIP and H.323 compatible VoIP, IP-Telephony and Videoconferencing application that allows you to make audio and video calls to remote users with SIP and H.323 hardware or software.");
- 
+
   license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
                                _(license[2]), "\n\n", NULL);
 
@@ -216,8 +153,8 @@ GNU GPL for all the rest of the software thus combined.")
 
 
 void
-help_cb (G_GNUC_UNUSED GtkWidget *widget,
-	 G_GNUC_UNUSED gpointer data)
+help_callback (G_GNUC_UNUSED GtkWidget *widget,
+	       G_GNUC_UNUSED gpointer data)
 {
 #ifdef WIN32
   gchar *locale, *loc_ , *index_path;
@@ -258,22 +195,13 @@ help_cb (G_GNUC_UNUSED GtkWidget *widget,
   GError *err = NULL;
   gboolean success = FALSE;
 
-#ifdef HAVE_GNOME
-  success = gnome_help_display (PACKAGE_NAME ".xml", NULL, &err);
-#elif GTK_CHECK_VERSION(2, 13, 1)
   success = gtk_show_uri (NULL, "ghelp:" PACKAGE_NAME, GDK_CURRENT_TIME, &err);
-#else
-  success = FALSE;
-  err = g_error_new_literal (g_quark_from_static_string ("ekiga"),
-                             0,
-			     _("Help display is not supported by your GTK+ version"));
-#endif
 
   if (!success) {
     GtkWidget *d;
-    d = gtk_message_dialog_new (GTK_WINDOW (GnomeMeeting::Process ()->GetMainWindow ()), 
+    d = gtk_message_dialog_new (GTK_WINDOW (GnomeMeeting::Process ()->GetMainWindow ()),
                                 (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
-                                GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
+                                GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
                                 "%s", _("Unable to open help file."));
     gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (d),
                                               "%s", err->message);
@@ -286,7 +214,7 @@ help_cb (G_GNUC_UNUSED GtkWidget *widget,
 
 
 void
-quit_callback (G_GNUC_UNUSED GtkWidget *widget, 
+quit_callback (G_GNUC_UNUSED GtkWidget *widget,
 	       G_GNUC_UNUSED gpointer data)
 {
   GtkWidget *main_window = NULL;
@@ -295,21 +223,19 @@ quit_callback (G_GNUC_UNUSED GtkWidget *widget,
   GtkWidget *accounts_window = NULL;
 
   main_window = GnomeMeeting::Process ()->GetMainWindow ();
-  assistant_window = GnomeMeeting::Process ()->GetAssistantWindow (false);
-  prefs_window = GnomeMeeting::Process ()->GetPrefsWindow (false);
+  assistant_window = GnomeMeeting::Process ()->GetAssistantWindow ();
+  prefs_window = GnomeMeeting::Process ()->GetPrefsWindow ();
   accounts_window = GnomeMeeting::Process ()->GetAccountsWindow ();
-  
+
   gtk_widget_hide (main_window);
   if (assistant_window)
-    gnomemeeting_window_hide (assistant_window);
+    gm_window_hide (assistant_window);
   if (prefs_window)
-    gnomemeeting_window_hide (prefs_window);
-  gnomemeeting_window_hide (accounts_window);
+    gm_window_hide (prefs_window);
+  gm_window_hide (accounts_window);
 
   while (gtk_events_pending ())
     gtk_main_iteration ();
 
   gtk_main_quit ();
-}  
-
-
+}
